@@ -24,64 +24,21 @@ SOFTWARE.
 from .version import __version__
 from .request import HTTPClient, Route, ResponseStatusCode, ResponseParser
 from .components import Components, RemoveComponents, InlineKeyboard, Keyboard
-from .attachments.audio import Audio
-from .attachments.location import Location
-from .attachments.document import Document
-from .attachments.photo import Photo
+from .attachments import *
+from .payments import *
 from .payments import Price, Invoice
 from .user import User
 from .attachments.contact import ContactMessage
 from .chat import Chat, ChatType
 from .message import Message
 from .permissions import Permissions
-from .chatmember import ChatMember, MemberRole
+from .chatmember import ChatMember, ChatMemberStatus
 from .callbackquery import CallbackQuery
 from .update import Update, UpdateType
 from .updater import Updater, EventType
 from .error import BaleError, APIError, NetworkError, HTTPException, TimeOut, NotFound, Forbidden, HTTPClientError, InvalidToken, RateLimited
 from .bot import Bot
 
-
-__all__ = (
-    "Bot",
-    "CallbackQuery",
-    "Update",
-    "UpdateType",
-    "Chat",
-    "ChatType",
-    "Message",
-    "User",
-    "Updater",
-    "EventType",
-    "Components",
-    "RemoveComponents",
-    "Keyboard",
-    "InlineKeyboard",
-    "Location",
-    "Audio",
-    "Document",
-    "Photo",
-    "ContactMessage",
-    "Invoice",
-    "Price",
-    "Permissions",
-    "ChatMember",
-    "MemberRole",
-    "BaleError",
-    "APIError",
-    "RateLimited",
-    "InvalidToken",
-    "Forbidden",
-    "NetworkError",
-    "TimeOut",
-    "NotFound",
-    "HTTPException",
-    "HTTPClientError",
-    "HTTPClient",
-    "Route",
-    "ResponseParser",
-    "ResponseStatusCode",
-)
-
 __title__ = "python-bale-bot"
 __author__ = "Kian Ahmadian"
+__license__ = 'MIT'
