@@ -3,11 +3,4 @@ from .audio import Audio
 from .contact import ContactMessage
 from .location import Location
 from .photo import Photo
-
-__all__ = (
-	"Document",
-	"Audio",
-	"ContactMessage",
-	"Location",
-	"Photo"
-)
+from .video import Video
